

clear all
%close all

fpath = '..\runs\1D\Roller\WSE_BC\JB07\eddy\';
fpath = '..\runs\1D\Roller\WSE_BC\JB07\Van-Rijn\';
fpath = '..\runs\Roller\JB07\Lund-CIRP\test2\';
fpath = '..\runs\Roller\JB07\Lund-CIRP\';
fpath = '..\runs\Roller\JB07\Van-Rijn\';

scale = 1.0; 
trans_form = 'Lund-CIRP';
trans_form = 'van Rijn';
% trans_form = 'Soulsby-van Rijn';

%measured
Hsm = load('..\data\bc1_measured_hs.dat');
etam = load('..\data\bc1_measured_eta.dat');
um = load('..\data\bc1_measured_v.dat');
Qsm = load('..\data\bc1_measured_sed.dat');
hm = load('..\data\bc1_measured_depth.dat');
xs = 1.38;

%Grid
filename = [fpath,'Flow_bc1_grid.h5'];
info = hdf5info(filename);
s = info.GroupHierarchy.Groups;
nx = s.Attributes(7).Value;
ny = s.Attributes(8).Value;
origin = s.Attributes(6).Value;
x = hdf5read(s.Datasets(1));
y = hdf5read(s.Datasets(2));
%x = x - origin(1) - xs;
x = x - 0.25 - xs;
depth = hdf5read(s.Groups(1).Groups(2).Datasets(4));
depth = reshape(depth,[nx,ny])';

%calculated
filename = [fpath,'Flow_bc1_sol.h5'];
sol = readcmsh5(filename);
ind = 30;
% ind = 20;
%Water elevation
eta = reshape(sol.Water_Elevation.Values(:,end),[nx,ny]);
eta(eta<-900) = NaN;
%Current Magnitude
uv = reshape(sol.Current_Magnitude.Values(:,end),[nx,ny]);
uv(uv<-900) = NaN;
%U-velocity
u = reshape(sol.Current_Velocity.Values(1,:,end),[nx,ny])';
u(abs(u)>10) = NaN;
%V-velocity
v = reshape(sol.Current_Velocity.Values(2,:,end),[nx,ny])';
v(abs(v)>10) = NaN;
%Wave height
Hs = reshape(sol.Wave_Height.Values(:,end),[nx,ny]);
Hs(Hs<0) = NaN;
%Sediment Transport
fac = 60*60*24*365;
Qs = fac*reshape(sol.Total_Sediment_Transport.Values(2,:,end),[nx,ny])';
% Qs(abs(Qs)>10000) = NaN;

% return

%Depth
depth2 = depth(ind,:)';
%Transect
eta2 = eta(:,ind);
Hs2 = Hs(:,ind);
% v2 = uv(:,ind);
v2 = v(ind,:);
Qs2 = Qs(ind,:);

%Statistics
rmse = zeros(4,1);
rmae = zeros(4,1);
R2 = zeros(4,1);
B = zeros(4,1);

%Wave height
yc=interp1(x,Hs2,Hsm(:,1));
ym=Hsm(:,2);
rmse(1) = sqrt(mean((yc-ym).^2));
rmae(1) = abs(mean((yc-ym)))/max(abs(ym));
R = corrcoef(yc,ym);
R2(1) = R(1,2).^2;
B(1) = mean(ym) - mean(yc);

%Water level
yc=interp1(x,eta2,etam(:,1));
ym=etam(:,2);
ind = isfinite(yc);
rmse(2) = sqrt(mean((yc(ind)-ym(ind)).^2));
rmae(2) = abs(mean((yc(ind)-ym(ind))))/max(abs(ym(ind)));
R = corrcoef(yc(ind),ym(ind));
R2(2) = R(1,2).^2;
B(2) = mean(ym) - mean(yc);

%Longshore current
yc=interp1(x,-v2,um(:,1));
ym=um(:,2);
rmse(3) = sqrt(mean((yc-ym).^2));
rmae(3) = abs(mean((yc-ym)))/max(abs(ym));
R = corrcoef(yc,ym);
R2(3) = R(1,2).^2;
B(3) = mean(ym) - mean(yc);

%Sediment Transport
yc=interp1(x,-Qs2,Qsm(4:end,1));
ym=Qsm(4:end,2);
ind = isfinite(yc);
rmse(4) = sqrt(mean((yc(ind)-ym(ind)).^2));
rmae(4) = abs(mean((yc(ind)-ym(ind))))/max(abs(ym));
R = corrcoef(yc(ind),ym(ind));
R2(4) = R(1,2).^2;
B(4) = mean(ym) - mean(yc);

% figure, plot(yc,ym,'.'), axis equal

disp('--- LSTF Case 1 Goodness of Fit Statistics ---')
disp('Transect    Hs     eta      V      Qt')
fprintf(1,'RMSE    %7.4f,%7.4f,%7.4f,%7.4f\n',rmse);
fprintf(1,'RMAE    %7.4f,%7.4f,%7.4f,%7.4f\n',rmae);
fprintf(1,'R^2     %7.3f,%7.3f,%7.3f,%7.3f\n',R2);
fprintf(1,'Bias    %7.3f,%7.3f,%7.3f,%7.3f\n',B);

% return
%---- Plotting --------------
%Sediment transport
figure('position',[361   276   560   279])
q2=400;
[ax,h1,h2] = plotyy(x,-Qs2*scale,hm(:,1),hm(:,2));
set(h1,'color','k','linewidth',1)
set(h2,'color','k','linewidth',2,'linestyle','--')
set(ax(1),'xlim',[0,18],'ylim',q2*[-1 1],'YColor','k')
set(ax(2),'xlim',[0,18],'ylim',[-0.8 0.8],'ydir','reverse','YColor','k')
set(ax(1),'ytick',linspace(-q2,q2,9),'position',[0.13 0.14 0.775 0.75])
set(ax(2),'ytick',linspace(-0.8,0.8,9),'position',[0.13 0.14 0.775 0.75])
set(ax(1),'nextplot','add')
plot(ax(1),Qsm(:,1),Qsm(:,2),'ok','Markerfacecolor','k')
xlabel('Distance, m')
ylabel(ax(1),'Longshore Sediment Transport, m^3/m/year')
ylabel(ax(2),'Bed Elevation, m SWL')
title(['LSTF Case 1, ',trans_form])
legend('Calculated','Measured','Bed Elevation',0)
set(gcf,'PaperPositionMode','auto')
saveas(gcf,['..\images\LSTF_C1_SedPro_',trans_form,'.png']) 
% print(gcf,'-dpng','..\images\LSTF_C1_SedPro')

% return

%Wave height
figure('position',[361   276   560   279])
[ax,h1,h2] = plotyy(x,Hs2,hm(:,1),hm(:,2));
set(h1,'color','k','linewidth',1)
set(h2,'color','k','linewidth',2,'linestyle','--')
set(ax(1),'xlim',[0,18],'ylim',[-0.3 0.3],'YColor','k')
set(ax(2),'xlim',[0,18],'ylim',[-0.8 0.8],'ydir','reverse','YColor','k')
set(ax(1),'ytick',linspace(-0.3,0.3,9),'position',[0.13 0.14 0.775 0.75])
set(ax(2),'ytick',linspace(-0.8,0.8,9),'position',[0.13 0.14 0.775 0.75])
set(ax(1),'nextplot','add')
plot(ax(1),Hsm(:,1),Hsm(:,2),'ok','Markerfacecolor','k')
xlabel('Distance, m')
ylabel(ax(1),'Significant Wave Height, m')
ylabel(ax(2),'Bed Elevation, m SWL')
title('LSTF Case 1')
legend('Calculated','Measured','Bed Elevation',0)
set(gcf,'PaperPositionMode','auto')
saveas(gcf,'..\images\LSTF_C1_WavePro.png') 

%Longshore current
figure('position',[361   276   560   279])
[ax,h1,h2] = plotyy(x,-v2,hm(:,1),hm(:,2));
set(h1,'color','k','linewidth',1)
set(h2,'color','k','linewidth',2,'linestyle','--')
set(ax(1),'xlim',[0,18],'ylim',[-0.2 0.2],'YColor','k')
set(ax(2),'xlim',[0,18],'ylim',[-0.8 0.8],'ydir','reverse','YColor','k')
set(ax(1),'ytick',linspace(-0.2,0.2,9),'position',[0.13 0.14 0.775 0.75])
set(ax(2),'ytick',linspace(-0.8,0.8,9),'position',[0.13 0.14 0.775 0.75])
set(ax(1),'nextplot','add')
plot(ax(1),um(:,1),um(:,2),'ok','Markerfacecolor','k')
xlabel('Distance, m')
ylabel(ax(1),'Longshore Current, m/s')
ylabel(ax(2),'Bed Elevation, m SWL')
title('LSTF Case 1')
legend('Calculated','Measured','Bed Elevation',0)
set(gcf,'PaperPositionMode','auto')
saveas(gcf,'..\images\LSTF_C1_CurrentPro.png') 

%Water level
figure('position',[361   276   560   279])
e2=0.02;
[ax,h1,h2] = plotyy(x,eta2,hm(:,1),hm(:,2));
set(h1,'color','k','linewidth',1)
set(h2,'color','k','linewidth',2,'linestyle','--')
set(ax(1),'xlim',[0,18],'ylim',e2*[-1 1],'YColor','k')
set(ax(2),'xlim',[0,18],'ylim',[-0.8 0.8],'ydir','reverse','YColor','k')
set(ax(1),'ytick',linspace(-e2,e2,9),'position',[0.13 0.14 0.775 0.75])
set(ax(2),'ytick',linspace(-0.8,0.8,9),'position',[0.13 0.14 0.775 0.75])
set(ax(1),'nextplot','add')
plot(ax(1),etam(:,1),etam(:,2),'ok','Markerfacecolor','k')
xlabel('Distance, m')
ylabel(ax(1),'Water Level, m')
ylabel(ax(2),'Bed Elevation, m SWL')
title('LSTF Case 1')
legend('Calculated','Measured','Bed Elevation',0)
set(gcf,'PaperPositionMode','auto')
saveas(gcf,'..\images\LSTF_C1_ElevPro.png') 

return
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure
contourf(x,y,uv')
hold on
plot(x,ones(size(x))*y(ind),'k')
ix = 2;
jy = 4;
quiver(x(1:ix:end),y(1:jy:end),...
    u(1:jy:end,1:ix:end),v(1:jy:end,1:ix:end),'k')
set(gca,'ydir','normal','DataAspectRatio',[1,1,1])
ylabel('Distance, m')
xlabel('Distance, m')
title('Currents, m/s')
colorbar
saveas(gcf,'..\images\LSTF_Case1_Currents.tif') 

figure
contourf(x,y,Hs',20)
hold on
plot(x,ones(size(x))*y(ind),'k')
set(gca,'ydir','normal','DataAspectRatio',[1,1,1])
ylabel('Distance, m')
xlabel('Distance, m')
title('Hs, m')
colorbar
saveas(gcf,'..\images\LSTF_Case1_Waves.tif') 

figure
contourf(x,y,eta')
hold on
plot(x,ones(size(x))*y(ind),'k')
set(gca,'ydir','normal','DataAspectRatio',[1,1,1])
ylabel('Distance, m')
xlabel('Distance, m')
title('Water Level, m')
colorbar
saveas(gcf,'..\images\LSTF_Case1_Water_Levels.tif') 

return

figure('position',[423   116   421   484]);
subplot(2,1,1)
plot(x,Hs2,'b-',Hsm(:,1),Hsm(:,2),'ok','Markerfacecolor','k')
set(gca,'xlim',[0,20],'ylim',[0 0.3])
ylabel('Significant Wave Height, m')
title('LSTF BC-1')

subplot(2,1,2)
% plot(x,depth2,'b-','Markerfacecolor','k')
plot(hm(:,1),hm(:,2),'.k',x,depth2,'b-','Markerfacecolor','k')
set(gca,'xlim',[0,20],'ylim',[0 0.8],'ydir','reverse')
ylabel('Depth, m')
xlabel('Distance, m')

% return
figure('position',[423   116   421   484]);
subplot(2,1,1)
plot(x,-v2,'b-',um(:,1),um(:,2),'ok','Markerfacecolor','k')
set(gca,'xlim',[0,20],'ylim',[-0.05,0.2])
ylabel('Longshore Current Velocity, m/s')
title('LSTF BC-1')

subplot(2,1,2)
% plot(x,depth2,'b-','Markerfacecolor','k')
plot(hm(:,1),hm(:,2),'.k',x,depth2,'b-','Markerfacecolor','k')
set(gca,'xlim',[0,20],'ylim',[0 0.8],'ydir','reverse')
ylabel('Depth, m')
xlabel('Distance, m')

figure('position',[423   116   421   484]);
subplot(2,1,1)
plot(x,eta2,'b-',etam(:,1),etam(:,2),'ok','Markerfacecolor','k')
set(gca,'xlim',[0,20],'ylim',[-0.005 0.02])
ylabel('Water Level, m')
title('LSTF BC-1')

subplot(2,1,2)
plot(x,depth2,'b-','Markerfacecolor','k')
%plot(hm(:,1),hm(:,2),'.k',x,depth2,'b-','Markerfacecolor','k')
set(gca,'xlim',[0,20],'ylim',[0 0.8],'ydir','reverse')
ylabel('Depth, m')
xlabel('Distance, m')

sec2year = 60*60*24*365;

figure('position',[423   116   421   484]);
subplot(2,1,1)
plot(x,-Qs2*sec2year,'b-',Qsm(:,1),Qsm(:,2),'ok','Markerfacecolor','k')
set(gca,'xlim',[0,20]) %,'ylim',[-0.005 0.02])
ylabel('Water Level, m')
title('LSTF BC-1')

subplot(2,1,2)
plot(x,depth2,'b-','Markerfacecolor','k')
%plot(hm(:,1),hm(:,2),'.k',x,depth2,'b-','Markerfacecolor','k')
set(gca,'xlim',[0,20],'ylim',[0 0.8],'ydir','reverse')
ylabel('Depth, m')
xlabel('Distance, m')




return


